@@ -11,11 +11,11 @@ import (
 	"strings"
 	"sync"
 
+	"dario.cat/mergo"
 	"github.com/AlekSi/pointer"
 	"github.com/Masterminds/semver/v3"
 	"github.com/goreleaser/chglog"
 	"github.com/goreleaser/nfpm/v2/files"
-	"github.com/imdario/mergo"
 	"gopkg.in/yaml.v3"
 )
 
@@ -171,6 +171,18 @@ func (c *Config) expandEnvVarsStringSlice(items []string) []string {
 	return items
 }
 
+func (c *Config) expandEnvVarsContents(contents files.Contents) files.Contents {
+	for i := range contents {
+		f := contents[i]
+		if !f.Expand {
+			continue
+		}
+		f.Destination = strings.TrimSpace(os.Expand(f.Destination, c.envMappingFunc))
+		f.Source = strings.TrimSpace(os.Expand(f.Source, c.envMappingFunc))
+	}
+	return contents
+}
+
 func (c *Config) expandEnvVars() {
 	// Version related fields
 	c.Info.Release = os.Expand(c.Info.Release, c.envMappingFunc)
@@ -185,6 +197,7 @@ func (c *Config) expandEnvVars() {
 		c.Overrides[or].Recommends = c.expandEnvVarsStringSlice(c.Overrides[or].Recommends)
 		c.Overrides[or].Provides = c.expandEnvVarsStringSlice(c.Overrides[or].Provides)
 		c.Overrides[or].Suggests = c.expandEnvVarsStringSlice(c.Overrides[or].Suggests)
+		c.Overrides[or].Contents = c.expandEnvVarsContents(c.Overrides[or].Contents)
 	}
 	c.Info.Conflicts = c.expandEnvVarsStringSlice(c.Info.Conflicts)
 	c.Info.Depends = c.expandEnvVarsStringSlice(c.Info.Depends)
@@ -192,6 +205,7 @@ func (c *Config) expandEnvVars() {
 	c.Info.Recommends = c.expandEnvVarsStringSlice(c.Info.Recommends)
 	c.Info.Provides = c.expandEnvVarsStringSlice(c.Info.Provides)
 	c.Info.Suggests = c.expandEnvVarsStringSlice(c.Info.Suggests)
+	c.Info.Contents = c.expandEnvVarsContents(c.Info.Contents)
 
 	// Basic metadata fields
 	c.Info.Name = os.Expand(c.Info.Name, c.envMappingFunc)
@@ -235,6 +249,7 @@ func (c *Config) expandEnvVars() {
 	for k, v := range c.Info.Deb.Fields {
 		c.Info.Deb.Fields[k] = os.Expand(v, c.envMappingFunc)
 	}
+	c.Info.Deb.Predepends = c.expandEnvVarsStringSlice(c.Info.Deb.Predepends)
 }
 
 // Info contains information about a single package.
@@ -308,7 +323,7 @@ type Overridables struct {
 	Suggests   []string       `yaml:"suggests,omitempty" json:"suggests,omitempty" jsonschema:"title=suggests directive,example=nfpm"`
 	Conflicts  []string       `yaml:"conflicts,omitempty" json:"conflicts,omitempty" jsonschema:"title=conflicts directive,example=nfpm"`
 	Contents   files.Contents `yaml:"contents,omitempty" json:"contents,omitempty" jsonschema:"title=files to add to the package"`
-	Umask      os.FileMode    `yaml:"umask,omitempty" json:"umask,omitempty" jsonschema:"title=umask for file contents,example=002"`
+	Umask      os.FileMode    `yaml:"umask,omitempty" json:"umask,omitempty" jsonschema:"title=umask for file contents,example=112"`
 	Scripts    Scripts        `yaml:"scripts,omitempty" json:"scripts,omitempty" jsonschema:"title=scripts to execute"`
 	RPM        RPM            `yaml:"rpm,omitempty" json:"rpm,omitempty" jsonschema:"title=rpm-specific settings"`
 	Deb        Deb            `yaml:"deb,omitempty" json:"deb,omitempty" jsonschema:"title=deb-specific settings"`
@@ -351,6 +366,13 @@ type PackageSignature struct {
 	KeyFile       string  `yaml:"key_file,omitempty" json:"key_file,omitempty" jsonschema:"title=key file,example=key.gpg"`
 	KeyID         *string `yaml:"key_id,omitempty" json:"key_id,omitempty" jsonschema:"title=key id,example=bc8acdd415bd80b3"`
 	KeyPassphrase string  `yaml:"-" json:"-"` // populated from environment variable
+	// SignFn, if set, will be called with the package-specific data to sign.
+	// For deb and rpm packages, data is the full package content.
+	// For apk packages, data is the SHA1 digest of control tgz.
+	//
+	// This allows for signing implementations other than using a local file
+	// (for example using a remote signer like KMS).
+	SignFn func(data io.Reader) ([]byte, error) `yaml:"-" json:"-"` // populated when used as a library
 }
 
 type RPMSignature struct {
@@ -383,6 +405,7 @@ type Deb struct {
 	Signature   DebSignature      `yaml:"signature,omitempty" json:"signature,omitempty" jsonschema:"title=signature"`
 	Compression string            `yaml:"compression,omitempty" json:"compression,omitempty" jsonschema:"title=compression algorithm to be used,enum=gzip,enum=xz,enum=none,default=gzip"`
 	Fields      map[string]string `yaml:"fields,omitempty" json:"fields,omitempty" jsonschema:"title=fields"`
+	Predepends  []string          `yaml:"predepends,omitempty" json:"predepends,omitempty" jsonschema:"title=predepends directive,example=nfpm"`
 }
 
 type DebSignature struct {
